// FROG_Events.h: interface for the FROG_Events class.
//
//////////////////////////////////////////////////////////////////////

#ifndef _FROG_EVENTS_H__
#define _FROG_EVENTS_H__

#include <algorithm>
#include <iostream>
#include <vector>
#include <map>

#include "FROG_Chunk.h"
#include "FROG_Element_Tools.h"
#include "FROG_Geometry.h"
#include "FROG_Element_Base_With_DetId.h"
#include "FROG_Element_Event.h"
#include "FROG_Objects_Extended.h"
#include "FROG_Net_Tools.h"

#ifdef FROG_ZLIB
	#include "FROG_ZLib.h"
#endif 

class FROG_Events
{
public :
	FROG_Element_Base*        prim;    
	FROG_Objects_Extended*    frogObjects_;
	unsigned int              Current_Event;

	std::vector<unsigned int> EventToDisplay;
	std::vector<unsigned int> OpenedMenu;
private :
	std::vector<string>  FilesPath_;
			 int CurrentFile_;
	unsigned int CurrentSize_;
public:
	FROG_Events(FROG_Objects_Extended* frogObjects=NULL) : prim(NULL),frogObjects_(frogObjects), Current_Event(0), CurrentFile_(-1), CurrentSize_(0){
		prim = new FROG_Element_Base(C_PRIMARY);

	}
	~FROG_Events(){  delete prim; /*delete frogObjects_;*/  }

	void AddEvent(FROG_Element_Event* event);

	void Load ();
	void Load (std::vector<string>& FilesFromCard);
	void Load (const char* path);
	void Load (int CurrentFile);

	void Save (const char* path);	
	bool SaveInLive (const char* path, bool CloseFile=false, bool CompressFiles=true, unsigned int MaxSize=(unsigned int)-1);
    void Save (const char* path, bool CompressFiles=true);	
	
    FROG_Element_Event* GoToEvent(int i);
    FROG_Element_Event* NextEvent();
    FROG_Element_Event* PreviousEvent();

    void NextFile();
    void PreviousFile();
	const char* CurrentFile();

    FROG_Element_Event* getCurrentEvent() const {
		if( Current_Event<prim->getDaughterSize() )
			return dynamic_cast<FROG_Element_Event*>(prim->getDaughter(Current_Event));
        return NULL; 
	}

    int NumberOfEvents() const { return prim->getDaughterSize(); }

	void keepEventToDisplay(FROG_Element_Base* mother);
	void readEventToDisplay(FROG_ReadCards* Card);
	void updateEventToDisplay(unsigned int EvtIdToFlip=0);
    void removeDisplayList(FROG_Element_Base* mother);

	void keepOpenedMenu(FROG_Element_Base* mother);
	void updateOpenedMenu();
};

#endif
